History
-------

1.10 (2011-11-09)
+++++++++++++++++
* Moved modules around to make them more pythonish
* Updated LICENSE and added header to all .py files

1.00 (2011-11-06)
+++++++++++++++++
* Initial Release
